import { BasicColumn, FormSchema } from '@/components/Table';

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '类型',
    dataIndex: 'category',
    width: 120,
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 140,
  },
];
export const SearchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'isKinship',
    component: 'Checkbox',
    label: '仅看血缘对象',
    colProps: { span: 8 },
    labelWidth: 120,
  },
];
export const storageManagementColumns: BasicColumn[] = [
  {
    title: '清理开始时间',
    dataIndex: 'startTime',
    width: 120,
  },
  {
    title: '清理结束时间',
    dataIndex: 'endTime',
    width: 120,
  },
  {
    title: '执行耗时',
    dataIndex: 'useTime',
    width: 80,
  },
  {
    title: '执行状态',
    dataIndex: 'status',
    width: 120,
  },
  {
    title: '清理策略',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '清理表顶点数',
    dataIndex: 'pointNum',
    width: 120,
  },
  {
    title: '清理血缘关系数',
    dataIndex: 'num',
    width: 120,
  },
  {
    title: '操作者',
    dataIndex: 'user',
    width: 80,
  },
];
export const storageManagementFormSchema: FormSchema[] = [
  {
    field: 'startTime',
    label: '清理开始时间',
    component: 'DatePicker',
    colProps: { lg: 4, md: 4 },
  },
  {
    field: 'endTime',
    label: '清理结束时间',
    component: 'DatePicker',
    colProps: { lg: 4, md: 4 },
  },
  {
    field: 'user',
    label: '清理者',
    component: 'Input',
    colProps: { lg: 4, md: 4 },
  },
  {
    field: 'type',
    label: '清理策略',
    component: 'Select',
    componentProps: {
      options: [
        { label: '手动清理', value: '1' },
        { label: '自动清理', value: '2' },
      ],
    },
    colProps: { lg: 4, md: 4 },
  },
];
export const ruleTypeSchema: FormSchema[] = [
  {
    field: 'flag',
    label: '清理方式',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '手动清理', value: '0' },
        { label: '自动清理', value: '1' },
      ],
    },
    defaultValue: '0',
    required: true,
  },
  {
    field: 'cycleTime',
    label: '清理周期',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
    itemProps: {
      extra: 'Cron表达式',
    },
    required: true,
    ifShow: ({ model }) => model.flag === '1',
  },
];
export const ruleSchema: FormSchema[] = [
  {
    field: 'flag',
    label: '清理方案',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '时间', value: '0' },
        { label: '记录', value: '1' },
      ],
    },
    defaultValue: '0',
    required: true,
  },
  {
    field: 'dateNum',
    label: '保留天数',
    component: 'Input',
    colProps: { lg: 12, md: 12 },
    defaultValue: '7',
    itemProps: {
      extra: '保留输入天数内的血缘，推荐保留7天以上',
    },
    required: true,
  },
  {
    field: 'isKinship',
    component: 'Checkbox',
    label: '清理已删除对象',
    colProps: { lg: 24, md: 24 },
  },
];
